@@ -1,4 +1,4 @@
-## Copyright (C) 2018 John Donoghue <john.donoghue@ieee.org>
+## Copyright (C) 2018-2019 John Donoghue <john.donoghue@ieee.org>
 ## 
 ## This program is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -37,10 +37,20 @@ function retval = boardTypeString (id)
       retval = "nano";
     case 5
       retval = "uno_wifi_r2";
+    case 6
+      retval = "nano_every";
     case 10
       retval = "lilypad";
     case 20
       retval = "promini";
+    case 21
+      retval = "promicro";
+    case 22
+      retval = "leonardo";
+    case 23
+      retval = "micro";
+    #case 40
+    #  retval = "zero";
     case 41
       retval = "sparkfunsamd21";
     otherwise
